@@ -60,27 +60,27 @@ class BootstrapButtonSetColumn(DataTableColumn):
 
 class BootstrapInfoButton(BootstrapButtonColumn):
     def __init__(self, text, link, icon='', size=None, title_class=None, title_width="85px", title='', field='id'):
-        BootstrapButtonColumn.__init__(text, 'info', link, icon, size, title_class, title_width, title, field)
+        BootstrapButtonColumn.__init__(self, text, 'info', link, icon, size, title_class, title_width, title, field)
 
 
 class BootstrapSuccessButton(BootstrapButtonColumn):
     def __init__(self, text, link, icon='', size=None, title_class=None, title_width="85px", title='', field='id'):
-        BootstrapButtonColumn.__init__(text, 'success', link, icon, size, title_class, title_width, title, field)
+        BootstrapButtonColumn.__init__(self, text, 'success', link, icon, size, title_class, title_width, title, field)
 
 
 class BootstrapErrorButton(BootstrapButtonColumn):
     def __init__(self, text, link, icon='', size=None, title_class=None, title_width="85px", title='', field='id'):
-        BootstrapButtonColumn.__init__(text, 'error', link, icon, size, title_class, title_width, title, field)
+        BootstrapButtonColumn.__init__(self, text, 'error', link, icon, size, title_class, title_width, title, field)
 
 
 class BootstrapWarningButton(BootstrapButtonColumn):
     def __init__(self, text, link, icon='', size=None, title_class=None, title_width="85px", title='', field='id'):
-        BootstrapButtonColumn.__init__(text, 'warning', link, icon, size, title_class, title_width, title, field)
+        BootstrapButtonColumn.__init__(self, text, 'warning', link, icon, size, title_class, title_width, title, field)
 
 
 class BootstrapPrimaryButton(BootstrapButtonColumn):
     def __init__(self, text, link, icon='', size=None, title_class=None, title_width="85px", title='', field='id'):
-        BootstrapButtonColumn.__init__(text, 'primary', link, icon, size, title_class, title_width, title, field)
+        BootstrapButtonColumn.__init__(self, text, 'primary', link, icon, size, title_class, title_width, title, field)
 
 
 class StaticLinkDataTableColumn(DataTableColumn):
