@@ -2,7 +2,7 @@
 from django.template import TemplateSyntaxError, Node
 from django.template.defaulttags import register
 from django_helpers.helpers.templatetags import parse_args
-from django_helpers.apps.data_tables import get_table
+from django_helpers.apps.data_tables.views import get_table
 
 __author__ = 'ajumell'
 
