@@ -1,9 +1,11 @@
 # coding=utf-8
-from django_helpers.helpers.views import render_to_string
 from django.forms import widgets
-from django_helpers.templatetags.static_manger import add_js_file, require_jquery
+
+from django_helpers.helpers.views import render_to_string
+from django_helpers.apps.static_manager import jQueryURL
 from django_helpers.apps.forms.widgets import Widget
 
+
 __author__ = 'ajumell'
 
 
@@ -13,9 +15,7 @@ class TinyMCEEditorOptions(object):
 
 class TinyMCEWidget(Widget, widgets.Textarea):
     def __init__(self, *args, **kwargs):
-        require_jquery()
-        add_js_file('tiny_mce/tiny_mce.js')
-        add_js_file('tiny_mce/jquery.tinymce.js')
+        self.js_files = [jQueryURL, 'tiny_mce/tiny_mce.js', 'tiny_mce/jquery.tinymce.js']
         widgets.Textarea.__init__(self, *args, **kwargs)
 
     def render_js(self):
