@@ -14,10 +14,11 @@
 """
 from django_helpers import create_attr_from_obj, get_settings_val
 from django_helpers.helpers.views import render_to_string
-from django_helpers.templatetags.static_manger import add_js_file, require_jquery, add_css_file, add_jquery_easing
+from django_helpers.apps.static_manager import add_css_file, jQueryUIURL, jQueryEasingURL
 
 __author__ = 'ajumell'
 
+
 class SuperSizedTransitions(object):
     none = 'none'
     fade = 'fade'
@@ -28,6 +29,7 @@ class SuperSizedTransitions(object):
     carouselRight = 'carouselRight'
     carouselLeft = 'carouselLeft'
 
+
 TransitionChoices = []
 
 for item in dir(SuperSizedTransitions):
@@ -67,13 +69,13 @@ class SuperSized(object):
     show_thumbnails = False
     hide_controls = False
 
-
     def __init__(self):
-        require_jquery()
-        add_jquery_easing()
-
-        add_js_file('super-sized/js/supersized.3.2.7.min.js')
-        add_js_file('super-sized/theme/supersized.shutter.min.js')
+        self.js_files = [
+            jQueryUIURL,
+            jQueryEasingURL,
+            'super-sized/js/supersized.3.2.7.min.js',
+            'super-sized/theme/supersized.shutter.min.js'
+        ]
 
         add_css_file('super-sized/css/supersized.css')
         add_css_file('super-sized/theme/supersized.shutter.css')
@@ -90,7 +92,6 @@ class SuperSized(object):
             'url': link
         })
 
-
     def render(self):
         attrs = create_attr_from_obj(self)
         attrs['slides'] = self._slides
@@ -103,5 +104,4 @@ class SuperSized(object):
         return self.render()
 
     def __str__(self):
-        return self.render()
-
+        return self.render()
\ No newline at end of file
