@@ -5,17 +5,6 @@ from django_helpers.apps.supersized import SuperSized
 from django_helpers.apps.supersized.models import SuperSizedSlider
 from django import template
 from django_helpers.helpers.templatetags import TemplateNode, parse_args
-from django_helpers.templatetags.static_manger import add_js_file, add_css_file, require_jquery, add_jquery_easing
-
-
-require_jquery()
-add_jquery_easing()
-
-add_js_file('super-sized/js/supersized.3.2.7.min.js')
-add_js_file('super-sized/theme/supersized.shutter.min.js')
-
-add_css_file('super-sized/css/supersized.css')
-add_css_file('super-sized/theme/supersized.shutter.css')
 
 
 class SuperSizedNode(TemplateNode):
@@ -34,15 +23,17 @@ class SuperSizedNode(TemplateNode):
             try:
                 thumb = img.image.thumbnail
             except Exception, dt:
-                print 'Error :',dt
+                print 'Error :', dt
                 thumb = url
             caption = img.caption
             link = img.link
             slider.add_slide(url, caption, thumb, link)
         return unicode(slider)
 
+
 register = template.Library()
 
+
 @register.tag
 def super_sized(parser, token):
     bits = token.split_contents()
