@@ -121,8 +121,7 @@ class JavascriptMinify(object):
             next2 = read(1)
             if not next2:
                 last = next1.strip()
-                if not (doing_single_comment or doing_multi_comment) \
-                    and last not in ('', '/'):
+                if not (doing_single_comment or doing_multi_comment) and last not in ('', '/'):
                     write(last)
                 break
             if doing_multi_comment:
@@ -150,23 +149,19 @@ class JavascriptMinify(object):
                         in_quote = ''
                         write(''.join(quote_buf))
             elif next1 in '\r\n':
-                if previous_non_space in newlineend_strings \
-                    or previous_non_space > '~':
+                if previous_non_space in newlineend_strings or previous_non_space > '~':
                     while 1:
                         if next2 < '!':
                             next2 = read(1)
                             if not next2:
                                 break
                         else:
-                            if next2 in newlinestart_strings \
-                                or next2 > '~' or next2 == '/':
+                            if next2 in newlinestart_strings or next2 > '~' or next2 == '/':
                                 do_newline = True
                             break
             elif next1 < '!' and not in_re:
                 # noinspection PyUnnecessaryBackslash
-                if (previous_non_space in space_strings \
-                        or previous_non_space > '~') \
-                    and (next2 in space_strings or next2 > '~'):
+                if (previous_non_space in space_strings or previous_non_space > '~') and (next2 in space_strings or next2 > '~'):
                     do_space = True
             elif next1 == '/':
                 if (previous in ';\n\r{}' or previous < '!') and next2 in '/*':
@@ -238,18 +233,21 @@ class RemoveLastComaNode(template.Node):
         return output
 
 
+# noinspection PyUnusedLocal
 def do_jsmin(parser, token):
     nodelist = parser.parse(('endjsmin',))
     parser.delete_first_token()
     return JsMinNode(nodelist)
 
 
+# noinspection PyUnusedLocal
 def do_jsrmln(parser, token):
     nodelist = parser.parse(('endjsrmln',))
     parser.delete_first_token()
     return JsRmLnNode(nodelist)
 
 
+# noinspection PyUnusedLocal
 def do_remove_last_coma(parser, token):
     nodelist = parser.parse(('endremovecoma',))
     parser.delete_first_token()
