@@ -14,7 +14,7 @@ def get_class_names(class_names):
 
 
 def generate_code(tag, attrs, text='', self_closing=False, start_only=False):
-    class_names = attrs.pop('class')
+    class_names = attrs.pop('class', None)
 
     if class_names is not None:
         attrs['class'] = get_class_names(class_names)
@@ -32,5 +32,10 @@ def generate_code(tag, attrs, text='', self_closing=False, start_only=False):
         html = format_html(string, tag, attrs)
     else:
         string = "<{0}{1}>{2}</{0}>"
-        html = format_html(string, tag, attrs, text)
-    return html
\ No newline at end of file
+        try:
+            html = format_html(string, tag, attrs, text)
+        except UnicodeError:
+            string = "<{0}{1}>%s</{0}>"
+            html = format_html(string, tag, attrs)
+            html = html % text
+    return mark_safe(html)
\ No newline at end of file
